@@ -29,7 +29,7 @@ class ProgramTester:
 					s.write("# Solution file. '#' denotes a comment, i.e., not part of the solution")
 					s.write("# Command arguments used to generate this output: {}".format(args))
 					for l in output:
-						s.write(l)
+						s.write("{}/n".format(l))
 		
 		
 	def build_program(self):
